@@ -15,21 +15,21 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"auto"} --- }
-#' {Automatically computes appropriate correlations for
+#' \item \code{"auto"} --- Automatically computes appropriate correlations for
 #' the data using Pearson's for continuous, polychoric for ordinal,
 #' tetrachoric for binary, and polyserial/biserial for ordinal/binary with
 #' continuous. To change the number of categories that are considered
 #' ordinal, use \code{ordinal.categories}
-#' (see \code{\link[EGAnet]{polychoric.matrix}} for more details)}
+#' (see \code{\link[EGAnet]{polychoric.matrix}} for more details)
 #' 
-#' \item{\code{"pearson"} --- }
-#' {Pearson's correlation is computed for all variables regardless of
-#' categories}
+#' \item \code{"cor_auto"} --- Uses \code{\link[qgraph]{cor_auto}} to compute correlations. 
+#' Arguments can be passed along to the function
 #' 
-#' \item{\code{"spearman"} --- }
-#' {Spearman's rank-order correlation is computed for all variables
-#' regardless of categories}
+#' \item \code{"pearson"} --- Pearson's correlation is computed for all 
+#' variables regardless of categories
+#' 
+#' \item \code{"spearman"} --- Spearman's rank-order correlation is computed 
+#' for all variables regardless of categories
 #' 
 #' }
 #' 
@@ -43,12 +43,10 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"pairwise"} --- }
-#' {Computes correlation for all available cases between
-#' two variables}
+#' \item \code{"pairwise"} --- Computes correlation for all available cases between
+#' two variables
 #' 
-#' \item{\code{"listwise"} --- }
-#' {Computes correlation for all complete cases in the dataset}
+#' \item \code{"listwise"} --- Computes correlation for all complete cases in the dataset
 #' 
 #' }
 #' 
@@ -58,19 +56,16 @@
 #' 
 #' \itemize{
 #' 
-#' \item{\code{"BGGM"} --- }
-#' {Computes the Bayesian Gaussian Graphical Model.
+#' \item \code{"BGGM"} --- Computes the Bayesian Gaussian Graphical Model.
 #' Set argument \code{ordinal.categories} to determine
 #' levels allowed for a variable to be considered ordinal.
-#' See \code{\link[BGGM]{estimate}} for more details}
+#' See \code{?BGGM::estimate} for more details
 #' 
-#' \item{\code{"glasso"} --- }
-#' {Computes the GLASSO with EBIC model selection.
-#' See \code{\link[EGAnet]{EBICglasso.qgraph}} for more details}
+#' \item \code{"glasso"} --- Computes the GLASSO with EBIC model selection.
+#' See \code{\link[EGAnet]{EBICglasso.qgraph}} for more details
 #' 
-#' \item{\code{"TMFG"} --- }
-#' {Computes the TMFG method.
-#' See \code{\link[EGAnet]{TMFG}} for more details}
+#' \item \code{"TMFG"} --- Computes the TMFG method.
+#' See \code{\link[EGAnet]{TMFG}} for more details
 #' 
 #' }
 #' 
@@ -103,12 +98,6 @@
 #'   data = wmt, model = "glasso"
 #' )
 #' 
-#' # BGGM with analytic solution
-#' bggm_network <- network.estimation(
-#'   data = wmt, model = "BGGM",
-#'   analytic = TRUE # faster example for CRAN
-#' )
-#' 
 #' # TMFG
 #' tmfg_network <- network.estimation(
 #'   data = wmt, model = "TMFG"
@@ -138,10 +127,10 @@
 #' @export
 #'
 # Compute networks for EGA ----
-# Updated 09.08.2023
+# Updated 24.10.2023
 network.estimation <- function(
     data, n = NULL,
-    corr = c("auto", "pearson", "spearman"),
+    corr = c("auto", "cor_auto", "pearson", "spearman"),
     na.data = c("pairwise", "listwise"),
     model = c("BGGM", "glasso", "TMFG"),
     network.only = TRUE,
@@ -151,13 +140,18 @@ network.estimation <- function(
 {
   
   # Argument errors (return data in case of tibble)
-  data <- network.estimation_errors(data, n, network.only, verbose)
+  data <- network.estimation_errors(data, n, network.only, verbose, ...)
   
   # Check for missing arguments (argument, default, function)
   corr <- set_default(corr, "auto", network.estimation)
   na.data <- set_default(na.data, "pairwise", network.estimation)
   model <- set_default(model, "glasso", network.estimation)
   
+  # Check for {BGGM}
+  if(model == "bggm"){
+    stop("Due to CRAN check issues, `model = \"BGGM\"` is not available at the moment.")
+  }
+  
   # Obtain ellipse arguments
   ellipse <- list(...)
   
@@ -170,7 +164,9 @@ network.estimation <- function(
     # Generic function to get necessary inputs
     output <- obtain_sample_correlations(
       data = data, n = n, corr = corr, 
-      na.data = na.data, verbose = verbose, ...
+      na.data = na.data, verbose = verbose, 
+      needs_usable = FALSE, # skips usable data check
+      ...
     )
     
     # Get correlations and sample size
@@ -189,48 +185,48 @@ network.estimation <- function(
   # For 'model = "BGGM"', take a different path...
   if(model == "bggm"){
   
-    # Obtain arguments for `BGGM`
-    bggm_estimate_ARGS <- obtain_arguments(
-      silent_load(BGGM::estimate), 
-      FUN.args = ellipse 
-    )
-    
-    # Check for override of 'type'
-    bggm_estimate_ARGS$type <- find_BGGM_type(data, ellipse)
-    
-    # Send 'data' and 'verbose' to arguments
-    bggm_estimate_ARGS$Y <- data
-    bggm_estimate_ARGS$progress <- verbose
-    
-    # Perform BGGM estimate
-    bggm_output <- do.call(
-      what = BGGM::estimate,
-      args = bggm_estimate_ARGS
-    )
-    
-    # Determine `select` arguments
-    ## Uses `overwrite_arguments` instead of
-    ## `obtain_arguments` because `BGGM::select`
-    ## is an S3method. It's possible to use
-    ## `BGGM:::select.estimate` but CRAN gets
-    ## mad about triple colons
-    bggm_select_ARGS <- overwrite_arguments(
-      list( # defaults for `BGGM:::select.estimate`
-        cred = 0.95, alternative = "two.sided"
-      ), ARGS = ellipse
-    )
-    
-    # Send 'bggm_output' to arguments
-    bggm_select_ARGS$object <- bggm_output
-    
-    # Perform BGGM select
-    bggm_select <- do.call(
-      what = BGGM::select,
-      args = bggm_select_ARGS
-    )
-    
-    # Obtain network (regardless of 'network.only')
-    estimated_network <- bggm_select$pcor_adj
+    # # Obtain arguments for `BGGM`
+    # bggm_estimate_ARGS <- obtain_arguments(
+    #   silent_load(BGGM::estimate), 
+    #   FUN.args = ellipse 
+    # )
+    # 
+    # # Check for override of 'type'
+    # bggm_estimate_ARGS$type <- find_BGGM_type(data, ellipse)
+    # 
+    # # Send 'data' and 'verbose' to arguments
+    # bggm_estimate_ARGS$Y <- data
+    # bggm_estimate_ARGS$progress <- verbose
+    # 
+    # # Perform BGGM estimate
+    # bggm_output <- do.call(
+    #   what = BGGM::estimate,
+    #   args = bggm_estimate_ARGS
+    # )
+    # 
+    # # Determine `select` arguments
+    # ## Uses `overwrite_arguments` instead of
+    # ## `obtain_arguments` because `BGGM::select`
+    # ## is an S3method. It's possible to use
+    # ## `BGGM:::select.estimate` but CRAN gets
+    # ## mad about triple colons
+    # bggm_select_ARGS <- overwrite_arguments(
+    #   list( # defaults for `BGGM:::select.estimate`
+    #     cred = 0.95, alternative = "two.sided"
+    #   ), ARGS = ellipse
+    # )
+    # 
+    # # Send 'bggm_output' to arguments
+    # bggm_select_ARGS$object <- bggm_output
+    # 
+    # # Perform BGGM select
+    # bggm_select <- do.call(
+    #   what = BGGM::select,
+    #   args = bggm_select_ARGS
+    # )
+    # 
+    # # Obtain network (regardless of 'network.only')
+    # estimated_network <- bggm_select$pcor_adj
     
   }else{ # Non-BGGM methods
     
@@ -249,6 +245,7 @@ network.estimation <- function(
     estimation_ARGS$n <- n
     estimation_ARGS$returnAllResults <- !network.only
     estimation_ARGS$verbose <- verbose
+    estimation_ARGS$needs_usable <- FALSE # skips usable data check
 
     # Perform estimation
     estimation_OUTPUT <- do.call(
@@ -276,12 +273,12 @@ network.estimation <- function(
   
   # Add methods attribute for BGGM
   ## Methods for GLASSO and TMFG are already there
-  if(model == "bggm"){
-    attr(estimated_network, "methods") <- c(
-      bggm_estimate_ARGS[c("type", "analytic", "prior_sd", "iter")],
-      bggm_select_ARGS[c("cred", "alternative")]
-    )
-  }
+  # if(model == "bggm"){
+  #   attr(estimated_network, "methods") <- c(
+  #     bggm_estimate_ARGS[c("type", "analytic", "prior_sd", "iter")],
+  #     bggm_select_ARGS[c("cred", "alternative")]
+  #   )
+  # }
   
   # Add "model", "corr", and "na.data" to attributes
   attr(estimated_network, "methods")[
@@ -296,16 +293,16 @@ network.estimation <- function(
     # BGGM or other model
     if(model == "bggm"){
       
-      # Set up results
-      return(
-        list(
-          estimated_network = estimated_network,
-          output = list(
-            bggm_estimate = bggm_output,
-            bggm_select = bggm_select[names(bggm_select) != "object"]
-          )
-        )
-      )
+      # # Set up results
+      # return(
+      #   list(
+      #     estimated_network = estimated_network,
+      #     output = list(
+      #       bggm_estimate = bggm_output,
+      #       bggm_select = bggm_select[names(bggm_select) != "object"]
+      #     )
+      #   )
+      # )
       
     }else{
       
@@ -332,8 +329,8 @@ network.estimation <- function(
 
 #' @noRd
 # Argument errors ----
-# Updated 19.08.2023
-network.estimation_errors <- function(data, n, network.only, verbose)
+# Updated 07.09.2023
+network.estimation_errors <- function(data, n, network.only, verbose, ...)
 {
   
   # 'data' errors
@@ -358,8 +355,13 @@ network.estimation_errors <- function(data, n, network.only, verbose)
   length_error(verbose, 1, "network.estimation")
   typeof_error(verbose, "logical", "network.estimation")
   
+  # Check for usable data
+  if(needs_usable(list(...))){
+    data <- usable_data(data, verbose)
+  }
+  
   # Return usable data in case of tibble
-  return(usable_data(data, verbose))
+  return(data)
   
 }
 
